==> muon-5.3.2.tar.xz: muon-5.3.2/updater/KActionMessageWidget.h <==
/***************************************************************************
 *   Copyright © 2013 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#ifndef KACTIONMESSAGEWIDGET_H
#define KACTIONMESSAGEWIDGET_H

#include <KMessageWidget>

class KActionMessageWidget : public KMessageWidget
{
    Q_OBJECT
    public:
        explicit KActionMessageWidget(QAction* action, QWidget* parent = 0);
        QAction* action() const { return m_action; }

    public slots:
        void reconsiderVisibility();

    private:
        QAction* m_action;
};

#endif // KACTIONMESSAGEWIDGET_H

==> muon_5.4.2.orig.tar.xz: muon-5.4.2/updater/KActionMessageWidget.h <==
/***************************************************************************
 *   Copyright © 2013 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#ifndef KACTIONMESSAGEWIDGET_H
#define KACTIONMESSAGEWIDGET_H

#include <KMessageWidget>

class KActionMessageWidget : public KMessageWidget
{
    Q_OBJECT
    public:
        explicit KActionMessageWidget(QAction* action, QWidget* parent = nullptr);
        QAction* action() const { return m_action; }

    public slots:
        void reconsiderVisibility();

    private:
        QAction* m_action;
};

#endif // KACTIONMESSAGEWIDGET_H
